% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/PeriodMean.R
\name{PeriodMean}
\alias{PeriodMean}
\title{Period Mean on multidimensional array objects}
\usage{
PeriodMean(
  data,
  dates = NULL,
  start = NULL,
  end = NULL,
  time_dim = "time",
  na.rm = FALSE,
  ncores = NULL
)
}
\arguments{
\item{data}{a multidimensional array with named dimensions.}

\item{dates}{a vector of dates or a multidimensional array of dates with named dimensions matching the dimensions on parameter 'data'. By default it is NULL, to select a period this parameter must be provided.}

\item{start}{an optional parameter to defined the initial date of the period to select from the data by providing a list of two elements: the initial date of the period and the initial month of the period. By default it is set to NULL and the indicator is computed using all the data provided in \code{data}.}

\item{end}{an optional parameter to defined the final date of the period to select from the data by providing a list of two elements: the final day of the period and the final month of the period. By default it is set to NULL and the indicator is computed using all the data provided in \code{data}.}

\item{time_dim}{a character string indicating the name of the function to compute the indicator. By default, it is set to 'ftime'. More than one dimension name matching the dimensions provided in the object \code{data$data} can be specified.}

\item{na.rm}{a logical value indicating whether to ignore NA values (TRUE) or  not (FALSE).}

\item{ncores}{an integer indicating the number of cores to use in parallel computation.}
}
\value{
A multidimensional array with named dimensions.
}
\description{
Period Mean computes the average (mean) of a given variable in a period.
Providing temperature data, two agriculture indices can be obtain by using this function:
\itemize{
 \item\code{GST}{Growing Season average Temperature: The average temperature  from April 1st to Octobe 31st}
 \item\code{SprTX}{Spring Average Maximum Temperature: The average daily maximum temperature from April 1st to May 31st}}
}
\examples{
exp <- CSTools::lonlat_prec$data
SA <- PeriodMean(exp, time_dim = 'ftime')

data <- array(rnorm(5 * 3 * 214 * 2),
                   c(memb = 5, sdate = 3, time = 214, lon = 2)) 
Dates <- c(seq(as.Date("01-04-2000", format = "\%d-\%m-\%Y"), 
                    as.Date("31-10-2000", format = "\%d-\%m-\%Y"), by = 'day'),
                seq(as.Date("01-04-2001", format = "\%d-\%m-\%Y"), 
                    as.Date("31-10-2001", format = "\%d-\%m-\%Y"), by = 'day'),
                seq(as.Date("01-04-2002", format = "\%d-\%m-\%Y"), 
                    as.Date("31-10-2002", format = "\%d-\%m-\%Y"), by = 'day'))
dim(Dates) <- c(time = 214, sdate = 3)
SprTX <- PeriodMean(data, Dates, start = list(1, 4), end = list(31, 5))
}
